@@ -312,6 +312,11 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 			time_divisions = calendar_config_get_time_divisions ();
 			ic_dur = icaldurationtype_from_int (time_divisions * 60);
 		}
+
+		if (in_top_canvas)
+			new_dtstart = dtstart + start_offset * 60;
+		else
+			new_dtstart = dtstart;
 		break;
 	case GNOME_CAL_WEEK_VIEW:
 	case GNOME_CAL_MONTH_VIEW:
@@ -319,16 +324,21 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 		if (old_dtstart.is_date && old_dtend.is_date
 			&& memcmp (&ic_dur, &ic_oneday, sizeof(ic_dur)) == 0)
 			all_day_event = TRUE;
+		else {
+			icaltimetype new_time = icaltime_from_timet_with_zone (dtstart, FALSE, default_zone);
+
+			new_time.hour = old_dtstart.hour;
+			new_time.minute = old_dtstart.minute;
+			new_time.second = old_dtstart.second;
+
+			new_dtstart = icaltime_as_timet_with_zone (new_time, default_zone);
+		}
 		break;
 	default:
 		g_assert_not_reached ();
 		return;
 	}
 	
-	if (in_top_canvas)
-		new_dtstart = dtstart + start_offset * 60;
-	else
-		new_dtstart = dtstart;
 
 	itime = icaltime_from_timet_with_zone (new_dtstart, FALSE, default_zone);
 	if (all_day_event)
@@ -802,10 +812,17 @@ clipboard_get_text_cb (GtkClipboard *clipboard, const gchar *text, ECalendarView
 		subcomp = icalcomponent_get_first_component (icalcomp, ICAL_ANY_COMPONENT);
 		while (subcomp) {
 			child_kind = icalcomponent_isa (subcomp);
-			if (child_kind == ICAL_VEVENT_COMPONENT)
+			if (child_kind == ICAL_VEVENT_COMPONENT) {
+
+				if (e_cal_util_component_has_recurrences (subcomp)) {
+					icalproperty *icalprop = icalcomponent_get_first_property (subcomp, ICAL_RRULE_PROPERTY);
+					if (icalprop) 
+						icalproperty_remove_parameter_by_name (icalprop, "X-EVOLUTION-ENDDATE");
+				}
+	
 				e_calendar_view_add_event (cal_view, client, selected_time_start, 
 							   default_zone, subcomp, in_top_canvas);
-			else if (child_kind == ICAL_VTIMEZONE_COMPONENT) {
+			} else if (child_kind == ICAL_VTIMEZONE_COMPONENT) {
 				icaltimezone *zone;
 
 				zone = icaltimezone_new ();
@@ -916,71 +933,79 @@ e_calendar_view_delete_selected_events (ECalendarView *cal_view)
 void
 e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 {
-	ECalendarViewEvent *event;
 	GList *selected;
-	const char *uid, *rid = NULL;
-	GError *error = NULL;
 	ECalComponent *comp;
-	struct icaltimetype itt;
-	ECalComponentDateTime dt;
-	icaltimezone *zone = NULL;
+	ECalendarViewEvent *event;
 		
 	selected = e_calendar_view_get_selected_events (cal_view);
 	if (!selected)
 		return;
-
+	
 	event = (ECalendarViewEvent *) selected->data;
-
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
-	e_cal_component_get_uid (comp, &uid);
 
-	e_cal_component_get_dtstart (comp, &dt);
-
-	if (dt.tzid) {
+	if (delete_component_dialog (comp, FALSE, 1, e_cal_component_get_vtype (comp), GTK_WIDGET (cal_view))) {
+		const char *uid, *rid = NULL;
 		GError *error = NULL;
+		ECalComponentDateTime dt;
+		icaltimezone *zone = NULL;
+		gboolean is_instance = FALSE;
 
-		e_cal_get_timezone (event->comp_data->client, dt.tzid, &zone, &error);
-		if (error) {
-			zone = e_calendar_view_get_timezone (cal_view);	
-			g_clear_error(&error);
-		}
-	} else 
-		zone = e_calendar_view_get_timezone (cal_view);
+		e_cal_component_get_uid (comp, &uid);
+		e_cal_component_get_dtstart (comp, &dt);
+		is_instance = e_cal_component_is_instance (comp);
 
-	itt = icaltime_from_timet_with_zone (event->comp_data->instance_start, TRUE, zone ? zone : icaltimezone_get_utc_timezone ());
+		if (dt.tzid) {
+			GError *error = NULL;
 
-	if (!e_cal_get_recurrences_no_master (event->comp_data->client)) 
-		rid = icaltime_as_ical_string (itt);
-	else
-		rid = e_cal_component_get_recurid_as_string (comp);
-
-	e_cal_component_free_datetime (&dt);
-	if (rid) {
-		if (delete_component_dialog (comp, FALSE, 1, e_cal_component_get_vtype (comp), GTK_WIDGET (cal_view))) {
-
-			if (itip_organizer_is_user (comp, event->comp_data->client)
-			    && cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
-							event->comp_data->client,
-							comp, TRUE) && !e_cal_get_save_schedules (event->comp_data->client)) {
-				if (!e_cal_component_is_instance (comp)) {
-					ECalComponentRange range;
-
-					/* set the recurrence ID of the object we send */
-					range.type = E_CAL_COMPONENT_RANGE_SINGLE;
-					e_cal_component_get_dtstart (comp, &range.datetime);
-					range.datetime.value->is_date = 1;
-					e_cal_component_set_recurid (comp, &range);
-
-					e_cal_component_free_datetime (&range.datetime);
-				}
-				itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL);
+			e_cal_get_timezone (event->comp_data->client, dt.tzid, &zone, &error);
+			if (error) {
+				zone = e_calendar_view_get_timezone (cal_view);	
+				g_clear_error(&error);
 			}
+		} else 
+			zone = e_calendar_view_get_timezone (cal_view);
 
-			e_cal_remove_object_with_mod (event->comp_data->client, uid, rid, CALOBJ_MOD_THIS, &error);
-			delete_error_dialog (error, E_CAL_COMPONENT_EVENT);
-			g_clear_error (&error);
+
+		if (is_instance)  
+			rid = e_cal_component_get_recurid_as_string (comp);
+
+		e_cal_component_free_datetime (&dt);
+
+
+		if (itip_organizer_is_user (comp, event->comp_data->client)
+				&& cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
+					event->comp_data->client,
+					comp, TRUE) && !e_cal_get_save_schedules (event->comp_data->client)) {
+			if (!e_cal_component_is_instance (comp)) {
+				ECalComponentRange range;
+
+				/* set the recurrence ID of the object we send */
+				range.type = E_CAL_COMPONENT_RANGE_SINGLE;
+				e_cal_component_get_dtstart (comp, &range.datetime);
+				range.datetime.value->is_date = 1;
+				e_cal_component_set_recurid (comp, &range);
+
+				e_cal_component_free_datetime (&range.datetime);
+			}
+			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL);
 		}
+
+		if (is_instance)
+			e_cal_remove_object_with_mod (event->comp_data->client, uid, rid, CALOBJ_MOD_THIS, &error);
+		else {
+			struct icaltimetype instance_rid;
+
+			instance_rid = icaltime_from_timet_with_zone (event->comp_data->instance_start, 
+					TRUE, zone ? zone : icaltimezone_get_utc_timezone ());
+			e_cal_util_remove_instances (event->comp_data->icalcomp, instance_rid, CALOBJ_MOD_THIS);
+			e_cal_modify_object (event->comp_data->client, event->comp_data->icalcomp, CALOBJ_MOD_THIS,
+				       	&error);
+		}
+
+		delete_error_dialog (error, E_CAL_COMPONENT_EVENT);
+		g_clear_error (&error);
 	}
 
 	/* free memory */
@@ -1653,12 +1678,20 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
 	ECalComponent *comp;
 	icalcomponent *icalcomp;
 	ECalComponentTransparency transparency;
+	ECal *default_client = NULL;
 	guint32 flags = 0;
 
 	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
 
 	priv = cal_view->priv;
 
+	default_client = e_cal_model_get_default_client (priv->model);
+
+	if (default_client && e_cal_get_load_state (default_client) != E_CAL_LOAD_LOADED) {
+		g_warning ("Default client not loaded \n");
+		return;
+	}
+	
 	dt.value = &itt;
 	if (all_day)
 		dt.tzid = NULL;
@@ -1807,7 +1840,7 @@ e_calendar_view_edit_appointment (ECalendarView *cal_view,
 		ECalComponent *comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 		flags |= COMP_EDITOR_MEETING;
-		if (itip_organizer_is_user (comp, client))
+		if (itip_organizer_is_user (comp, client) || !e_cal_component_has_attendees (comp))
 			flags |= COMP_EDITOR_USER_ORG;
 		g_object_unref (comp);
 	}
