@@ -53,6 +53,10 @@
 #include "print.h"
 #include "tasks-control.h"
 #include "evolution-shell-component-utils.h"
+#include "e-util/e-menu.h"
+#include "e-cal-menu.h"
+#include "e-util/e-menu.h"
+#include "itip-utils.h"
 
 #define FIXED_MARGIN                            .05
 
@@ -90,8 +94,15 @@ static void tasks_control_print_cmd		(BonoboUIComponent	*uic,
 static void tasks_control_print_preview_cmd	(BonoboUIComponent	*uic,
 						 gpointer		 data,
 						 const char		*path);
+static void tasks_control_assign_cmd           (BonoboUIComponent      *uic,
+                                                gpointer               data,
+                                                const char             *path);
 
+static void tasks_control_forward_cmd          (BonoboUIComponent      *uic,
+                                                gpointer               data,
+                                                const char             *path);
 
+	  
 BonoboControl *
 tasks_control_new (void)
 {
@@ -131,6 +142,40 @@ tasks_control_activate_cb		(BonoboControl		*control,
 		tasks_control_deactivate (control, tasks);
 }
 
+struct _tasks_sensitize_item {
+	char *command;
+	guint32 enable;
+};
+
+static void
+sensitize_items(BonoboUIComponent *uic, struct _tasks_sensitize_item *items, guint32 mask)
+{
+	while (items->command) {
+		char command[32];
+
+		g_assert(strlen(items->command)<21);
+		sprintf(command, "/commands/%s", items->command);
+
+		bonobo_ui_component_set_prop (uic, command, "sensitive",
+					      (items->enable & mask) == 0 ? "1" : "0",
+					      NULL);
+		items++;
+	}
+}
+
+static struct _tasks_sensitize_item tasks_sensitize_table[] = {
+	{ "TasksOpenTask", E_CAL_MENU_SELECT_ONE },
+	{ "TasksCut", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksCopy", E_CAL_MENU_SELECT_ANY },
+	{ "TasksPaste", E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksDelete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksMarkComplete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_NOTCOMPLETE},
+	{ "TasksPurge",  E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksAssign", E_CAL_MENU_SELECT_ONE | E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_ASSIGNABLE },
+	{ "TasksForward", E_CAL_MENU_SELECT_ONE },
+	{ 0 }
+};
+
 /* Sensitizes the UI Component menu/toolbar commands based on the number of
  * selected tasks.
  */
@@ -141,6 +186,11 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	gboolean read_only = TRUE;
 	ECal *ecal;
 	ECalModel *model;
+	ECalMenu *menu;
+	ECalMenuTargetSelect *t;
+	GPtrArray *events;
+	GSList *selected = NULL, *l = NULL;
+	ECalendarTable *cal_table;
 
 	uic = bonobo_control_get_ui_component (control);
 	g_assert (uic != NULL);
@@ -148,32 +198,27 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	if (bonobo_ui_component_get_container (uic) == CORBA_OBJECT_NIL)
 		return;
 
-	model = e_calendar_table_get_model (e_tasks_get_calendar_table (tasks));
-	ecal = e_cal_model_get_default_client (model);
-	if (ecal)
-		e_cal_is_read_only (ecal, &read_only, NULL);
+	menu = e_tasks_get_tasks_menu (tasks);
+	cal_table = e_tasks_get_calendar_table (tasks);
+	model = e_calendar_table_get_model (cal_table);
+	events = g_ptr_array_new ();
+	selected = e_calendar_table_get_selected (cal_table);
 
-	bonobo_ui_component_set_prop (uic, "/commands/TasksOpenTask", "sensitive",
-				      n_selected != 1 ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksCut", "sensitive",
-				      n_selected == 0 || read_only ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksCopy", "sensitive",
-				      n_selected == 0 ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksPaste", "sensitive",
-				      read_only ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksDelete", "sensitive",
-				      n_selected == 0 || read_only ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksMarkComplete", "sensitive",
-				      n_selected == 0 || read_only ? "0" : "1",
-				      NULL);
-	bonobo_ui_component_set_prop (uic, "/commands/TasksPurge", "sensitive",
-				      read_only ? "0" : "1",
-				      NULL);
+	for (l = selected;l;l = g_slist_next (l)) {
+		g_ptr_array_add (events, e_cal_model_copy_component_data ((ECalModelComponent *)l->data));
+	}
+
+	g_slist_free (selected);
+
+	t = e_cal_menu_target_new_select (menu, model, events);
+
+	ecal = e_cal_model_get_default_client (model);
+
+	if (ecal) 
+		e_cal_is_read_only (ecal, &read_only, NULL);
+		
+	sensitize_items (uic, tasks_sensitize_table, t->target.mask);
+	e_menu_update_target ((EMenu *)menu, (EMenuTarget *)t);
 }
 
 /* Callback used when the selection in the table changes */
@@ -198,7 +243,9 @@ static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB ("TasksPurge", tasks_control_purge_cmd),
 	BONOBO_UI_VERB ("TasksPrint", tasks_control_print_cmd),
 	BONOBO_UI_VERB ("TasksPrintPreview", tasks_control_print_preview_cmd),
-
+	BONOBO_UI_VERB ("TasksAssign", tasks_control_assign_cmd),
+        BONOBO_UI_VERB ("TasksForward", tasks_control_forward_cmd),
+     
 	BONOBO_UI_VERB_END
 };
 
@@ -235,6 +282,7 @@ tasks_control_activate (BonoboControl *control, ETasks *tasks)
 
 	g_signal_connect (tasks, "selection_changed", G_CALLBACK (selection_changed_cb), control);
 
+	e_menu_activate ((EMenu *)e_tasks_get_tasks_menu (tasks), uic, 1);
 	cal_table = e_tasks_get_calendar_table (tasks);
 	etable = e_calendar_table_get_table (cal_table);
 	n_selected = e_table_selected_count (etable);
@@ -259,6 +307,7 @@ tasks_control_deactivate (BonoboControl *control, ETasks *tasks)
 
 	g_assert (uic != NULL);
 
+	e_menu_activate ((EMenu *)e_tasks_get_tasks_menu (tasks), uic, 0);
 	e_tasks_set_ui_component (tasks, NULL);
 
 	e_tasks_discard_view_menus (tasks);
@@ -390,7 +439,6 @@ tasks_control_purge_cmd	(BonoboUIComponent	*uic,
 	ETasks *tasks;
 
 	tasks = E_TASKS (data);
-	
 	if (confirm_purge (tasks))
 	    e_tasks_delete_completed (tasks);
 }
@@ -433,3 +481,39 @@ tasks_control_print_preview_cmd (BonoboUIComponent *uic,
 	print_tasks (tasks, TRUE);
 }
 
+static void
+tasks_control_assign_cmd (BonoboUIComponent *uic,
+                         gpointer data,
+                         const char *path)
+{
+              ETasks *tasks;
+              ECalendarTable *cal_table;
+              ECalModelComponent *comp_data;
+
+              tasks = E_TASKS (data);
+              cal_table = e_tasks_get_calendar_table (tasks);
+              comp_data = e_calendar_table_get_selected_comp (cal_table);
+ 	       if (comp_data)
+              e_calendar_table_open_task (cal_table, comp_data, TRUE);
+}
+
+static void
+tasks_control_forward_cmd (BonoboUIComponent *uic,
+                         gpointer data,
+                          const char *path)
+{
+	        ETasks *tasks;
+               ECalendarTable *cal_table;
+               ECalModelComponent *comp_data;
+	
+               tasks = E_TASKS (data);
+               cal_table = e_tasks_get_calendar_table (tasks);
+               comp_data = e_calendar_table_get_selected_comp (cal_table);
+               if (comp_data) {
+                       ECalComponent *comp;
+                       comp = e_cal_component_new ();
+                       e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
+                       itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, comp_data->client, NULL, NULL);
+                       g_object_unref (comp);
+	       }
+}	       
