@@ -142,6 +142,7 @@ void
 em_vfolder_rule_add_source(EMVFolderRule *vr, const char *uri)
 {
 	g_assert(EM_IS_VFOLDER_RULE(vr));
+	g_return_if_fail (uri);
 	
 	vr->sources = g_list_append(vr->sources, g_strdup(uri));
 	
@@ -571,7 +572,7 @@ em_vfolder_editor_sourcelist_new(char *widget_name, char *string1, char *string2
 	
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_insert_column_with_attributes((GtkTreeView *)table, -1,
-						     _("vFolder source"), renderer,
+						     _("Search Folder source"), renderer,
 						     "text", 0, NULL);
 	
 	selection = gtk_tree_view_get_selection((GtkTreeView *)table);
